@@ -74,6 +74,9 @@ import numpy as np
 
 from .proplist import prop2abr, abr2prop, abr2key, properties
 from .version import __version__
+#JOAO
+from proplist import prop2key
+#JOAO
 
 __license__   = "MIT"
 __docformat__ = 'reStructuredText'
@@ -108,21 +111,13 @@ def query(comp='', numOfComp=0, year='', author='', keywords='', prop=''):
     :raises pyilt2.propertyError: if the abbreviation for physical property is invalid
     :raises pyilt2.queryError: if the database returns an Error on a query
     """
+
+    #JOAO
     if prop:
-        #JOAO
-        print("prop = ",prop)
-        #JOAO
-        if prop not in abr2prop.keys():
-            #JOAO
-            print("petara do baquila")
-            #JOAO
+        if prop not in prop2key.keys():
             raise propertyError(prop)
         else:
-            # prp = properties[prop][0]
-            prp = abr2key[prop]
-            #JOAO
-            print("prp: ",prp)
-            #JOAO
+            prp = prop2key[prop]
     else:
         prp = ''
     params = dict(
