@@ -257,6 +257,9 @@ def cliQuery(comp='', numOfComp=0, year='', author='', keywords='', prop='', ver
         print('Make query to NIST... ', end='')
         spinner.start()
     try:
+        #JOAO
+        print("entrou")
+        #JOAO
         resObj = query(comp=comp,
                               numOfComp=numOfComp,
                               year=year,
@@ -264,6 +267,9 @@ def cliQuery(comp='', numOfComp=0, year='', author='', keywords='', prop='', ver
                               keywords=keywords,
                               prop=prop)
     except:
+        #JOAO
+        print("excepto")
+        #JOAO
         if verbose:
             spinner.stop()
         e = sys.exc_info()[1]
@@ -272,6 +278,9 @@ def cliQuery(comp='', numOfComp=0, year='', author='', keywords='', prop='', ver
         #exit(1)
         #JOAO
     else:
+        #JOAO
+        print("balela")
+        #JOAO
         if verbose:
             spinner.stop()
             print('\b done! ({0:d} hits)'.format(len(resObj)))
